PCB Environment: py Namespace Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Functions
py Namespace Reference

## Data Structures
class | GIL_guard
| The GIL. More...
class | NPArray
class | Object
| NOTE: This does not do any automatic reference counting. More...
class | BorrowedRef
class | ObjectRef
struct | DictIterator

## Functions
template<typename Ty = PyObject>
Ty * | ValueError (const char *s)
| Error return helpers.
template<typename Ty = PyObject>
Ty * | MemoryError (const char *s)
template<typename Ty = PyObject>
Ty * | Exception (PyObject *exc, const char *s)
PyObject * | Exception (const std::exception &e)
PyObject * | String (const char *s)
| Conversion to Python.
PyObject * | String (const std::string &s)
bool | TupleN_Check (PyObject *py, uint n)
| Conversion from Python.
bool | TupleMin_Check (PyObject *py, uint n)
double | Number_AsDouble (PyObject *py)
bool | String_Check (PyObject *py)
std::string | String_AsStdString (PyObject *py)
std::string_view | String_AsStringView (PyObject *py)
std::string | String_AsStdString (PyObject *py, const char *error)
void | Dict_StealItemString (PyObject *dict, const char *key, PyObject *v)
void | Dict_StealItem (PyObject *dict, PyObject *key, PyObject *v)
void | DECREF_safe (PyObject *v)
PyObject * | None ()
PyObject * | NewRef (PyObject *py)
void | _capsuleDtor (PyObject *capsule)

## Function Documentation

## ◆ _capsuleDtor()

void py::_capsuleDtor | ( | PyObject * | capsule | ) |
| inline

## ◆ DECREF_safe()

void py::DECREF_safe | ( | PyObject * | v | ) |
| inline

## ◆ Dict_StealItem()

void py::Dict_StealItem | ( | PyObject * | dict,
|  | PyObject * | key,
|  | PyObject * | v )
| inline

## ◆ Dict_StealItemString()

void py::Dict_StealItemString | ( | PyObject * | dict,
|  | const char * | key,
|  | PyObject * | v )
| inline

## ◆ Exception() [1/2]

PyObject * py::Exception | ( | const std::exception & | e | ) |
| inline

## ◆ Exception() [2/2]

template<typename Ty = PyObject>

Ty * py::Exception | ( | PyObject * | exc,
|  | const char * | s )
| inline

## ◆ MemoryError()

template<typename Ty = PyObject>

Ty * py::MemoryError | ( | const char * | s | ) |
| inline

## ◆ NewRef()

PyObject * py::NewRef | ( | PyObject * | py | ) |
| inline

## ◆ None()

PyObject * py::None | ( |  | ) |
| inline

## ◆ Number_AsDouble()

double py::Number_AsDouble | ( | PyObject * | py | ) |
| inline

## ◆ String() [1/2]

PyObject * py::String | ( | const char * | s | ) |
| inline

Conversion to Python.

## ◆ String() [2/2]

PyObject * py::String | ( | const std::string & | s | ) |
| inline

## ◆ String_AsStdString() [1/2]

std::string py::String_AsStdString | ( | PyObject * | py | ) |
| inline

## ◆ String_AsStdString() [2/2]

std::string py::String_AsStdString | ( | PyObject * | py,
|  | const char * | error )
| inline

## ◆ String_AsStringView()

std::string_view py::String_AsStringView | ( | PyObject * | py | ) |
| inline

## ◆ String_Check()

bool py::String_Check | ( | PyObject * | py | ) |
| inline

## ◆ TupleMin_Check()

bool py::TupleMin_Check | ( | PyObject * | py,
|  | uint | n )
| inline

## ◆ TupleN_Check()

bool py::TupleN_Check | ( | PyObject * | py,
|  | uint | n )
| inline

Conversion from Python.

## ◆ ValueError()

template<typename Ty = PyObject>

Ty * py::ValueError | ( | const char * | s | ) |
| inline

Error return helpers.